function [MechEns] = alignSortMechData(DataMech,TrialSettings,Settings)
%alignSortMechData Align and sort the (bio)mechanical data
%   Analyze the (bio)mechanical data in the time-domain by aligning data at
%   stretch/perturbation onsets and combining them into a single ensemble. 
%   Function checks based on segment length whether enough data is 
%   available before/after index.
%
%	SYNTAX
%   [MechEns] = alignSortMechData(DataMech,Settings)
%
%	INPUTS
%	DataMech      = Selection of (bio)mechanical signals (struct)
%   TrialSettings = All settings used for current trial in AchillesGUI (struct)
%   Settings      = Overview of all processing settings (struct)
%
%   OUTPUT
%   MechEns = Aligned and sorted (bio)mechanical signals (struct)

    % Create processing settings and time vector
    segStart = round(Settings.tSegStart/DataMech.dt);
    segEnd   = round(Settings.tSegEnd/DataMech.dt);
    MechEns.tSeg = (0:segEnd-1)'*DataMech.dt;
    
    % Low-pass filter to help obtain velocity/acceleration
    [tfFiltNum,tfFiltDen] = dZOHLpFilter(Settings.fcLpPos*2*pi,1,DataMech.dt);
    posLp = filtfilt(tfFiltNum,tfFiltDen,DataMech.posMeas);
    % Calculate velocity/acceleration with numerical differentiation
    velLpGrad = gradient(posLp)/DataMech.dt;
    accLpGrad = gradient(velLpGrad)/DataMech.dt;

    % Retrieve mechanical start indices for stretch reflexes
    MechEns.stretchIdxs = getStretchIndices(DataMech.posRef,TrialSettings);
    MechEns.stretchIdxs = MechEns.stretchIdxs((MechEns.stretchIdxs > segStart) & (MechEns.stretchIdxs < (length(DataMech.posRef)-segEnd))); % Missing Achilles data

    % Pre-allocate ensemble data structure
    MechEns.rise = struct('posRef',{},'pos',{},'vel',{},'acc',{},'tq',{},'tqBack',{});
    % Retrieve all the seperate mechanical responses to all perturbations
    MechEns.rise = getMechStretchEnsembles(MechEns.stretchIdxs,MechEns.rise,...
        segStart,segEnd,DataMech.posRef,DataMech.posMeas,DataMech.velMeas,accLpGrad,DataMech.tqMeas);
end