function [solCurve,taCurve,gmCurve,glCurve] = calcEMGTorqueCurve(OutputData,Settings)
%calcEMGTorqueCurve Calculate EMG-Torque curve
%   Process EMG data, preferable equal to general EMG processing within
%   study (currently high-pass filter, rectify, moving average), to
%   calculate EMG-Torque relationship.
%
%	SYNTAX
%   [solCurve,taCurve,gmCurve,glCurve] = calcEMGTorqueCurve(OutputData,Settings)
%
%	INPUTS
%   OutputData = Complete set of experimental data (struct)
%   Settings   = Overview of all processing settings (struct)
%
%   OUTPUTS
%   solCurve = Average Soleus activity across torque levels (Mx1 double)
%   taCurve  = Average Tibialis activity across torque levels (Mx1 double)
%   gmCurve  = Average Gastroc. Med. activity across torque levels (Mx1 double)
%   glCurve  = Average Gastroc. Lat. activity across torque levels (Mx1 double)

    % Retrieve all relevant outputs for post-trial analysis
    EMGData = OutputData.EMGData;
    TrialSettings = OutputData.TrialSettings;

    % Create high-pass filter, including settings
    filtHP = 5; filtOrder = 2;
    [bHpFilt,aHpFilt] = butter(filtOrder,filtHP/(TrialSettings.fsEMG/2),'high');
    % High-pass filter and rectify EMG signals
    solEMG = abs(filter(bHpFilt,aHpFilt,detrend(EMGData(1,:)','constant')));
    taEMG = abs(filter(bHpFilt,aHpFilt,detrend(EMGData(2,:)','constant')));
    gmEMG = abs(filter(bHpFilt,aHpFilt,detrend(EMGData(3,:)','constant')));
    glEMG = abs(filter(bHpFilt,aHpFilt,detrend(EMGData(4,:)','constant')));
    % Retrieve EMG at all torque levels (without transient -2s @ start; -1s @ end)
    [~,transLoc] = findpeaks(diff(OutputData.EMGData(5,:)),'MinPeakHeight',4e4);
    solCurve = mean(solEMG([transLoc, round(mean(diff(transLoc)))+transLoc(end)] + (-4*2048:-2049)'));
    taCurve = mean(taEMG([transLoc, round(mean(diff(transLoc)))+transLoc(end)] + (-4*2048:-2049)'));
    gmCurve = mean(gmEMG([transLoc, round(mean(diff(transLoc)))+transLoc(end)] + (-4*2048:-2049)'));
    glCurve = mean(glEMG([transLoc, round(mean(diff(transLoc)))+transLoc(end)] + (-4*2048:-2049)'));
    % Reconstruct all torque targets performed during trial
    torqueTargets = linspace(0,TrialSettings.torqueMax,TrialSettings.torqueSteps)';
    
    if (Settings.isPlot)
        % Plot Results
        figure;
            hold on;
            plot(torqueTargets,solCurve,'^','LineWidth',1)
            plot(torqueTargets,taCurve,'o','LineWidth',1)
            if (TrialSettings.torqueDirection == 1)
                title('Mean Response per Torque level: Dorsiflexion')
            else
                title('Mean Response per Torque level: Plantarflexion')
            end
            xlabel('Torque Level [Nm]')
            ylabel('Mean Response [mV]')
            legend({'Sol','TA'})
    end
end