function [DataHM] = calcHMCurve(EMGData,TrialSettings,SessionSettings)
%calcHMCurve Calculate H-M Recruitment curve 
%   Sort all data from H-M Recruitment trial, ensemble average and
%   processes to calculate a H-M recruitment curve
%
%	SYNTAX
%   [DataHM] = calcHMCurve(EMGData,TrialSettings,SessionSettings)
%
%	INPUTS
%   EMGData         = EMG measurement dataset (MxN double)
%   TrialSettings   = All settings used for current trial in AchillesGUI (struct)
%   SessionSettings = All settings used for current session in AchillesGUI (struct)
%
%   OUTPUT
%	DataHM = Selection of H-M Recruitment curve data (struct)

    % Define time-vector of response
    DataHM.t = (floor(TrialSettings.reflexWindow(1)*TrialSettings.fsEMG):ceil(TrialSettings.reflexWindow(2)*TrialSettings.fsEMG))/TrialSettings.fsEMG;

    % Retrieve all trigger peaks for stimulus onset, reshape in groups of 4
    [~,triggerPeaks] = findpeaks(EMGData(5,:),'MinPeakHeight',1e6);
    triggerPeaks = reshape(triggerPeaks,4,[])';
    % Pre-allocate all outcome measures
    responseWindow = [floor(TrialSettings.reflexWindow(1)*TrialSettings.fsEMG),ceil(TrialSettings.reflexWindow(2)*TrialSettings.fsEMG)];
    DataHM.solResponse = zeros([numel(DataHM.t),size(triggerPeaks)]);
    if isfield(SessionSettings.AcrossSession,'mWaveWindow')
        % Extended pre-allocation if H-M recruitment curve windows are available already
        mWaveWindow = SessionSettings.AcrossSession.mWaveWindow;
        hReflexWindow = SessionSettings.AcrossSession.hReflexWindow;
        solMWave = zeros([diff(mWaveWindow)+1,size(triggerPeaks)]);
        solHReflex = zeros([diff(hReflexWindow)+1,size(triggerPeaks)]);
        DataHM.mWaveSize = zeros(size(triggerPeaks));
        DataHM.hReflexSize = zeros(size(triggerPeaks));
    end

    % Create EMG high-pass filter and apply to SOL EMG
    [bHpFilt,aHpFilt] = butter(TrialSettings.filtOrder,TrialSettings.filtHP/(TrialSettings.fsEMG/2),'high');
    solHpEMG = filter(bHpFilt,aHpFilt,EMGData(1,:)');
    % Retrieve all ensembles and peak-to-peak values
    for ii = 1:size(triggerPeaks,1)
        for jj = 1:size(triggerPeaks,2)
            % Store EMG response within stimulation response window
            DataHM.solResponse(:,ii,jj) = solHpEMG(triggerPeaks(ii,jj)+responseWindow(1):triggerPeaks(ii,jj)+responseWindow(2));
            if isfield(SessionSettings.AcrossSession,'mWaveWindow')
                % Process H-M recruitment curve with set mWave & hReflex windows
                solMWave(:,ii,jj) = solHpEMG(triggerPeaks(ii,jj)+mWaveWindow(1):triggerPeaks(ii,jj)+mWaveWindow(2));
                solHReflex(:,ii,jj) = solHpEMG(triggerPeaks(ii,jj)+hReflexWindow(1):triggerPeaks(ii,jj)+hReflexWindow(2));
                % Store H-M magnitudes using peak-to-peak value
                DataHM.mWaveSize(ii,jj) = max(solMWave(:,ii,jj)) - min(solMWave(:,ii,jj));
                DataHM.hReflexSize(ii,jj) = max(solHReflex(:,ii,jj)) - min(solHReflex(:,ii,jj));
            end
        end
    end
end