function [MVC,movMeanSol] = calcMVC(varargin)
%calcMVC Calculate MVC value
%   Process EMG data, preferable equal to general EMG processing within
%   study (currently high-pass filter, rectify, moving average), to
%   calculate maximum value as MVC.
%
%	SYNTAX
%   [MVC,movMeanSol] = calcMVC(EMGData,TrialSettings) {Online}
%   [MVC,movMeanSol] = calcMVC(OutputData)            {Post-trial}
%
%	INPUTS
%   EMGData       = EMG measurement dataset (MxN double)
%   TrialSettings = All settings used for current trial in AchillesGUI (struct)
%   OutputData    = Complete set of experimental data (struct)
%
%   OUTPUTS
%   MVC        = Maximum Voluntary Contraction (double)
%   movMeanSol = Processed EMG data (high-pass filt., rect., moving-avg.) (Mx1 double) 

    % Retrieve all relevant outputs for post-trial analysis
    if (nargin == 1)
        OutputData = varargin{1};
        EMGData = OutputData.EMGData;
        TrialSettings = OutputData.TrialSettings;
    elseif (nargin == 2)
        EMGData = varargin{1};
        TrialSettings = varargin{2};
    end

    % High-pass filter and rectify EMG signal (1st EMG channel)
    [bHpFilt,aHpFilt] = butter(TrialSettings.filtOrder,TrialSettings.filtHP/(TrialSettings.fsEMG/2),'high');
    solEMG = abs(filter(bHpFilt,aHpFilt,detrend(EMGData(1,:)','constant')));
    % Apply moving average filter and take maximum as MVC
    movMeanSol = movmean(solEMG,[round(TrialSettings.movAvgWindow*TrialSettings.fsEMG) 0]);
    % Obtain maximum value as MVC (note, without first 3 seconds due to transient (filter) effects)
    MVC = max(movMeanSol(3*TrialSettings.fsEMG:end));
end