function [num,den] = dZOHLpFilter(wn,zeta,dt)
%dZOHLpFilter Create 2nd-order discrete-time low-pass filter
%   Create a 2nd-order discrete-time low-pass filter by a zero order hold z 
%   transform, analogous to the book "Computer Controlled Systems - theory 
%   and design" by Astrom and Wittenmark. The corresponding continuous time 
%   filter is given by:
%                                 wn^2
%                       ------------------------
%                       s^2 + 2*zeta*wn*s + wn^2
%	The outputs B and A are the numerator and denominator coefficients
%   respectively. These can be used in the FILTER function directly, i.e.:
%           a(1)*y(n) = b(1)*x(n) + b(2)*x(n-1) + ... + b(nb+1)*x(n-nb)
%                                 - a(2)*y(n-1) - ... - a(na+1)*y(n-na)
%
%	SYNTAX
%   [num,den] = dZOHLpFilter(wn,zeta,dt)
%
%	INPUTS
%	wn   = Eigen frequency [rad/s] (double)
%	zeta = Damping ratio [-] (double)
%   dt   = Sampling time [s] (double)
%
%	OUTPUTS
%	num = Numerator coefficients of rational transfer function [z] (3x1 double)
%	den = Denominator coefficients of rational transfer function [z] (3x1 double)

    % Create filter for all under- and over-damped systems
    if ((zeta < 1) && (zeta > 0))
        w1 = wn*sqrt(1-zeta^2);
        bet = cos(w1*dt);
        gam = sin(w1*dt);
        alp = exp(-zeta*wn*dt);

        th = zeta*wn*gam/w1;

        a1 = -2*alp*bet;
        a2 = alp^2;

        b1 = 1-alp*(bet+th);
        b2 = a2+alp*(th-bet);

        num = [0 b1 b2];
        den = [1 a1 a2];
    % Create filter for all critically damped systems
    else 
        alp = exp(-wn*dt);
        ap = [1 -alp];
        num = [0 1-alp*(1+wn*dt) alp*(alp+wn*dt-1)]; 
        den = conv(ap,ap);
    end
end