function [StoreData] = getEMGStretchEnsembles(EMGIdx,StoreData,segStart,segEnd,solEMG,taEMG,gmEMG,glEMG,posEMG)
%getEMGStretchEnsembles Retrieve EMG response ensembles to stretches
%   Retrieve all the seperate EMG response ensembles to all stretches
%   starting at the provided EMG data indices.
%
%	SYNTAX
%   [StoreData] = getEMGStretchEnsembles(EMGIdx,StoreData,segStart,segEnd,solEMG,taEMG,gmEMG,glEMG,posEMG)
%
%	INPUTS
%   EMGIdx    = Set of start indices for stretch reflexes in EMG data (Mx1 double)
%	StoreData = Total ensembled, segmented EMG dataset (struct)
%   segStart  = Number of samples before EMGIdx at start of segments (double)
%   segEnd    = Number of samples after EMGIdx at end of segments (double)
%   solEMG    = Soleus EMG data vector (Nx1 double)
%   taEMG     = Tibialis Anterior EMG data vector (Nx1 double)
%   gmEMG     = Gastrocnemius Medialis EMG data vector (Nx1 double)
%   glEMG     = Gastrocnemius Lateralis EMG data vector (Nx1 double)
%   posEMG    = Reference position vector from EMG (Nx1 double)
%
%   OUTPUT
%	StoreData = Total ensembled, segmented EMG dataset (struct)

    % Pre-allocate the output
    StoreData(1).solBack = zeros(segStart,numel(EMGIdx)); StoreData.taBack   = zeros(segStart,numel(EMGIdx));
    StoreData.gmBack     = zeros(segStart,numel(EMGIdx)); StoreData.glBack   = zeros(segStart,numel(EMGIdx));
    StoreData.solReflex  = zeros(segEnd,numel(EMGIdx));   StoreData.taReflex = zeros(segEnd,numel(EMGIdx));
    StoreData.gmReflex   = zeros(segEnd,numel(EMGIdx));   StoreData.glReflex = zeros(segEnd,numel(EMGIdx));
    StoreData.posReflex  = zeros(segEnd,numel(EMGIdx));
    for jj = 1:numel(EMGIdx)
        % Windows given via segStart/segEnd variables
        StoreData.solBack(:,jj) = solEMG(EMGIdx(jj)-segStart:EMGIdx(jj)-1);
        StoreData.taBack(:,jj)  = taEMG(EMGIdx(jj)-segStart:EMGIdx(jj)-1);
        StoreData.gmBack(:,jj)  = gmEMG(EMGIdx(jj)-segStart:EMGIdx(jj)-1);
        StoreData.glBack(:,jj)  = glEMG(EMGIdx(jj)-segStart:EMGIdx(jj)-1);
        StoreData.solReflex(:,jj) = solEMG(EMGIdx(jj):EMGIdx(jj)+(segEnd-1));
        StoreData.taReflex(:,jj)  = taEMG(EMGIdx(jj):EMGIdx(jj)+(segEnd-1));
        StoreData.gmReflex(:,jj)  = gmEMG(EMGIdx(jj):EMGIdx(jj)+(segEnd-1));
        StoreData.glReflex(:,jj)  = glEMG(EMGIdx(jj):EMGIdx(jj)+(segEnd-1));
        StoreData.posReflex(:,jj) = posEMG(EMGIdx(jj):EMGIdx(jj)+(segEnd-1));
    end
end