function [StoreData] = getMechStretchEnsembles(mechIdx,StoreData,segStart,segEnd,posRef,posMeas,velMeas,accMeas,tqMeas)
%getMechStretchEnsembles Retrieve (bio)mechanical response ensembles to stretches
%   Retrieve all the seperate mechanical response ensembles to all stretches
%   starting at the provided mechanical data indices.
%
%	SYNTAX
%   [StoreData] = getMechStretchEnsembles(mechIdx,storeData,segStart,segEnd,posRef,posMeas,velMeas,accMeas,tqMeas)
%
%	INPUTS
%   mechIdx   = Set of start indices for stretch reflexes in mechanial data (Mx1 double)
%	StoreData = Total ensembled, segmented (bio)mechanical dataset (struct)
%   segStart  = Number of samples before mechIdx at start of segments (double)
%   segEnd    = Number of samples after mechIdx at end of segments (double)
%   posRef    = Reference position vector for motor (Mx1 double)
%   posMeas   = Measured position vector at motor encoder (Mx1 double)
%   velMeas   = Measured velocity vector at motor encoder (Mx1 double)
%   accMeas   = Measured acceleration vector at motor encoder (Mx1 double)
%   tqMeas    = Measured torque vector at force sensor (Mx1 double)
%
%   OUTPUT
%	StoreData = Total ensembled, segmented (bio)mechanical dataset (struct)

    % Pre-allocate the output
    StoreData(1).posRef = zeros(segEnd,numel(mechIdx));
    StoreData.pos       = zeros(segEnd,numel(mechIdx));
    StoreData.vel       = zeros(segEnd,numel(mechIdx));
    StoreData.acc       = zeros(segEnd,numel(mechIdx));
    StoreData.tq        = zeros(segEnd,numel(mechIdx));
    StoreData.tqBack    = zeros(segStart,numel(mechIdx));
    for jj = 1:numel(mechIdx)
        % Windows given via segStart/segEnd variables
        StoreData.posRef(:,jj) = posRef(mechIdx(jj)+(0:segEnd-1));
        StoreData.pos(:,jj)    = posMeas(mechIdx(jj)+(0:segEnd-1));
        StoreData.vel(:,jj)    = velMeas(mechIdx(jj)+(0:segEnd-1));
        StoreData.acc(:,jj)    = accMeas(mechIdx(jj)+(0:segEnd-1));
        StoreData.tq(:,jj)     = tqMeas(mechIdx(jj)+(0:segEnd-1));
        StoreData.tqBack(:,jj) = tqMeas(mechIdx(jj)+(-segStart:-1));
    end
end