function [colorRGB] = plotColors(varargin)
%plotColors PhD Color scheme
%   Call (series of) RGB definitions for PhD color scheme. The color scheme
%   is build on 10 base colors (hues/saturations) with a sequence behind it
%   defining color variations in terms of lightness (lum). 
%
%	SYNTAX
%   {Single Color RGBs; colorIdx = scalar}
%   [colorRGB] = plotColors(colorIdx) {Base color}
%   [colorRGB] = plotColors(colorIdx,'dark') {Dark variation}
%   [colorRGB] = plotColors(colorIdx,'light') {Lighter variation}
%   [colorRGB] = plotColors(colorIdx,'lightest') {Lightest variation}
%   [colorRGB] = plotColors(colorIdx,lightIdx) {Custom light index (1=darkest variation; 9=lightest variation)}
%
%   {Colormap RGBs; colorIdxs = vector}
%   [colorRGB] = plotColors(colorIdxs) {Base colors}
%   [colorRGB] = plotColors(colorIdxs,'map') {Single color variations, numSteps = 9}
%   [colorRGB] = plotColors(colorIdxs,'map',numSteps) {Single color variations}

    % Get colors
    [fullColor,colorSequence] = getColorLibrary();
    
    if (nargin == 1)
        colorIdx = varargin{1};
        if (isscalar(colorIdx))
            % Single color (full)
            colorRGB = fullColor(colorIdx,:)/255;
        else
            % Color map
            colorRGB = fullColor(colorIdx,:)/255;
        end
    elseif(nargin == 2)
        if (ischar(varargin{2}))
            colorIdx = varargin{1};
            typeChar = varargin{2};
            switch typeChar
                case 'dark'
                    % Single color (dark)
                    colorRGB = colorSequence(1,:,colorIdx)/255;
                case 'light'
                    % Single color (light)
                    colorRGB = colorSequence(end-2,:,colorIdx)/255;
                case 'lightest'
                    % Single color (lightest)
                    colorRGB = colorSequence(end,:,colorIdx)/255;
                case 'map'
                    % Color map
                    colorRGB = colorSequence(:,:,colorIdx)/255;
            end
        elseif (numel(varargin{2})==1)
            lightIdx = varargin{2};
            % Single color (custom index)
            colorIdx = varargin{1};
            colorRGB = colorSequence(lightIdx,:,colorIdx)/255;
        end
    elseif (nargin == 3)
        % Sequence color
        colorIdx = varargin{1};
        numSteps = varargin{3};
        defaultSequence = colorSequence(:,:,colorIdx);
        if (numSteps < 6)
            colorRGB = interpSequence(numSteps,defaultSequence(1:end-2,:,:))/255;
        else
            colorRGB = interpSequence(numSteps,defaultSequence(1:end-1,:,:))/255;
        end
    end

    function colorSequenceInterp = interpSequence(n,colorSequence)
        x = linspace(1,n,size(colorSequence,1));
        xi = 1:n;
        colorSequenceInterp = zeros(n,3);
        for ii = 1:3
            colorSequenceInterp(:,ii) = pchip(x,colorSequence(:,ii),xi);
        end
    end

    function [fullColor,colorSequence] = getColorLibrary()
        %%% Full Range
        fullColor = ...
        [ 23 111 168; % Hue 136; Sat 180; Lum  90
         209  80  24; % Hue  12; Sat 190; Lum 110
          50 143  48; % Hue  79; Sat 120; Lum  90
         236 177  40; % Hue  28; Sat 200; Lum 130
         137  32 159; % Hue 193; Sat 160; Lum  90
         236 125 184; % Hue 219; Sat 180; Lum 170
          53 181 155; % Hue 112; Sat 130; Lum 110
          32  18 131; % Hue 165; Sat 180; Lum  70
         134 185  49; % Hue  55; Sat 140; Lum 110
         159 159 159];     % Hue/Sat   0; Lum 150

        colorSequence = zeros(9,3,14);
        %%% Sequential (#1 Denim)
        colorSequence(:,:,1) = ...
        [ 13  62  94;  % Hue 136; Sat 180; Lum  50
          18  86 131;  % Hue 136; Sat 180; Lum  70
          23 111 168;  % Hue 136; Sat 180; Lum  90
          29 135 205;  % Hue 136; Sat 180; Lum 110
          51 155 225;  % Hue 136; Sat 180; Lum 130
          88 173 231;  % Hue 136; Sat 180; Lum 150
         125 191 236;  % Hue 136; Sat 180; Lum 170
         181 219 244;  % Hue 136; Sat 180; Lum 200
         237 245 252]; % Hue 136; Sat 180; Lum 230

        %%% Saturated (#1 Denim)
        colorSequence(:,:,11) = ...
        [ 45  55  62;  % Hue 136; Sat 40; Lum  50
          62  77  87;  % Hue 136; Sat 40; Lum  70
          80  99 112;  % Hue 136; Sat 40; Lum  90
          98 121 136;  % Hue 136; Sat 40; Lum 110
         119 142 157;  % Hue 136; Sat 40; Lum 130
         143 163 175;  % Hue 136; Sat 40; Lum 150
         168 183 193;  % Hue 136; Sat 40; Lum 170
         205 214 220;  % Hue 136; Sat 40; Lum 200
         242 244 247]; % Hue 136; Sat 40; Lum 230

        %%% Sequential (#2 Chocolate)
        colorSequence(:,:,2) = ...
        [ 96  36  11;  % Hue  12; Sat 190; Lum  50
         133  51  16;  % Hue  12; Sat 190; Lum  70
         171  66  20;  % Hue  12; Sat 190; Lum  90
         209  80  24;  % Hue  12; Sat 190; Lum 110
         231 101  46;  % Hue  12; Sat 190; Lum 130
         235 130  84;  % Hue  12; Sat 190; Lum 150
         239 157 122;  % Hue  12; Sat 190; Lum 170
         247 199 179;  % Hue  12; Sat 190; Lum 200
         253 241 236]; % Hue  12; Sat 190; Lum 230

        %%% Saturated (#2 Chocolate)
        colorSequence(:,:,12) = ...
        [ 62  50  45;  % Hue  12; Sat 40; Lum  50
          87  69  62;  % Hue  12; Sat 40; Lum  70
         112  89  80;  % Hue  12; Sat 40; Lum  90
         136 109  98;  % Hue  12; Sat 40; Lum 110
         157 131 119;  % Hue  12; Sat 40; Lum 130
         175 153 143;  % Hue  12; Sat 40; Lum 150
         193 175 168;  % Hue  12; Sat 40; Lum 170
         220 209 205;  % Hue  12; Sat 40; Lum 200
         247 243 242]; % Hue  12; Sat 40; Lum 230

        %%% Sequential (#3 La Palma Green)
        colorSequence(:,:,3) = ...
        [ 28  80  27;  % Hue  79; Sat 120; Lum  50
          39 112  37;  % Hue  79; Sat 120; Lum  70
          50 143  48;  % Hue  79; Sat 120; Lum  90
          62 175  58;  % Hue  79; Sat 120; Lum 110
          83 197  80;  % Hue  79; Sat 120; Lum 130
         114 207 112;  % Hue  79; Sat 120; Lum 150
         146 218 143;  % Hue  79; Sat 120; Lum 170
         192 234 191;  % Hue  79; Sat 120; Lum 200
         239 250 239]; % Hue  79; Sat 120; Lum 230

        %%% Saturated (#3 La Palma Green)
        colorSequence(:,:,13) = ...
        [ 45  62  45;  % Hue  79; Sat 40; Lum  50
          63  87  62;  % Hue  79; Sat 40; Lum  70
          81 112  80;  % Hue  79; Sat 40; Lum  90
          99 136  98;  % Hue  79; Sat 40; Lum 110
         120 157 119;  % Hue  79; Sat 40; Lum 130
         145 175 143;  % Hue  79; Sat 40; Lum 150
         169 193 168;  % Hue  79; Sat 40; Lum 170
         205 220 205;  % Hue  79; Sat 40; Lum 200
         242 247 242]; % Hue  79; Sat 40; Lum 230

        %%% Sequential (#4 Bright Sun)
        colorSequence(:,:,4) = ...
        [ 98  71   9;  % Hue  28; Sat 200; Lum  50
         136  99  13;  % Hue  28; Sat 200; Lum  70
         175 128  16;  % Hue  28; Sat 200; Lum  90
         215 156  19;  % Hue  28; Sat 200; Lum 110
         236 177  40;  % Hue  28; Sat 200; Lum 130
         239 191  80;  % Hue  28; Sat 200; Lum 150
         242 205 119;  % Hue  28; Sat 200; Lum 170
         248 226 177;  % Hue  28; Sat 200; Lum 200
         253 248 236]; % Hue  28; Sat 200; Lum 230

        %%% Saturated (#4 Bright Sun)
        colorSequence(:,:,14) = ...
        [ 64  57  43;  % Hue  28; Sat  50; Lum  50
          90  81  58;  % Hue  28; Sat  50; Lum  70
         116 104  75;  % Hue  28; Sat  50; Lum  90
         141 126  92;  % Hue  28; Sat  50; Lum 110
         163 148 114;  % Hue  28; Sat  50; Lum 130
         180 168 139;  % Hue  28; Sat  50; Lum 150
         197 187 165;  % Hue  28; Sat  50; Lum 170
         221 216 204;  % Hue  28; Sat  50; Lum 200
         247 245 242]; % Hue  28; Sat  50; Lum 230

        %%% Sequential (#5 Purple Heart)
        colorSequence(:,:,5) = ...
        [ 75  18  88;  % Hue 193; Sat 160; Lum  50
         107  24 124;  % Hue 193; Sat 160; Lum  70
         137  32 159;  % Hue 193; Sat 160; Lum  90
         167  39 194;  % Hue 193; Sat 160; Lum 110
         188  61 216;  % Hue 193; Sat 160; Lum 130
         201  96 223;  % Hue 193; Sat 160; Lum 150
         214 131 231;  % Hue 193; Sat 160; Lum 170
         232 184 241;  % Hue 193; Sat 160; Lum 200
         250 237 252]; % Hue 193; Sat 160; Lum 230

        %%% Sequential (#6 Mauvelous)
        colorSequence(:,:,6) = ...
        [ 94  13  55;  % Hue 219; Sat 180; Lum  50
         131  18  78;  % Hue 219; Sat 180; Lum  70
         168  23  99;  % Hue 219; Sat 180; Lum  90
         205  29 121;  % Hue 219; Sat 180; Lum 110
         225  51 142;  % Hue 219; Sat 180; Lum 130
         231  88 163;  % Hue 219; Sat 180; Lum 150
         236 125 184;  % Hue 219; Sat 180; Lum 170
         244 181 215;  % Hue 219; Sat 180; Lum 200
         252 237 244]; % Hue 219; Sat 180; Lum 230

        %%% Sequential (#7 Shamrock)
        colorSequence(:,:,7) = ...
        [ 24  82  70;  % Hue 112; Sat 130; Lum  50
          34 115  99;  % Hue 112; Sat 130; Lum  70
          44 148 126;  % Hue 112; Sat 130; Lum  90
          53 181 155;  % Hue 112; Sat 130; Lum 110
          74 202 176;  % Hue 112; Sat 130; Lum 130
         107 211 190;  % Hue 112; Sat 130; Lum 150
         140 221 205;  % Hue 112; Sat 130; Lum 170
         189 236 226;  % Hue 112; Sat 130; Lum 200
         239 250 248]; % Hue 112; Sat 130; Lum 230

        %%% Sequential (#8 Persian Indigo)
        colorSequence(:,:,8) = ...
        [ 23  13  94;  % Hue 165; Sat 180; Lum  50
          32  18 131;  % Hue 165; Sat 180; Lum  70
          41  23 168;  % Hue 165; Sat 180; Lum  90
          51  29 205;  % Hue 165; Sat 180; Lum 110
          73  51 225;  % Hue 165; Sat 180; Lum 130
         106  88 231;  % Hue 165; Sat 180; Lum 150
         139 125 236;  % Hue 165; Sat 180; Lum 170
         189 181 244;  % Hue 165; Sat 180; Lum 200
         239 237 252]; % Hue 165; Sat 180; Lum 230

        %%% Sequential (#9 Limerick)
        colorSequence(:,:,9) = ...
        [ 61  84  22;  % Hue  55; Sat 140; Lum  50
          85 118  31;  % Hue  55; Sat 140; Lum  70
         109 152  39;  % Hue  55; Sat 140; Lum  90
         134 185  49;  % Hue  55; Sat 140; Lum 110
         155 206  70;  % Hue  55; Sat 140; Lum 130
         173 215 104;  % Hue  55; Sat 140; Lum 150
         191 224 137;  % Hue  55; Sat 140; Lum 170
         219 237 188;  % Hue  55; Sat 140; Lum 200
         247 251 238]; % Hue  55; Sat 140; Lum 230

        %%% Sequential (#10 Dark Gray)
        colorSequence(:,:,10) = ...
        [ 53  53  53;  % Hue   0; Sat   0; Lum  50
          74  74  74;  % Hue   0; Sat   0; Lum  70
          95  95  95;  % Hue   0; Sat   0; Lum  90
         116 116 116;  % Hue   0; Sat   0; Lum 110
         138 138 138;  % Hue   0; Sat   0; Lum 130
         159 159 159;  % Hue   0; Sat   0; Lum 150
         180 180 180;  % Hue   0; Sat   0; Lum 170
         212 212 212;  % Hue   0; Sat   0; Lum 200
         244 244 244]; % Hue   0; Sat   0; Lum 230
    end
end
