function plotStretchEnsembles(varargin)
%plotStretchEnsembles Process and plot stretch reflex ensembles
%   Sort all data from control/baseline trial, ensemble average and
%   processes to show M1-M2 EMG stretch reflex responses
%
%	SYNTAX
%   plotStretchEnsembles(EMGEns,TrialSettings,SessionSettings) {Online}
%   plotStretchEnsembles(OutputData)                           {Post-trial}
%
%	INPUTS
%   EMGEns          = Aligned and sorted EMG signals (struct)
%   TrialSettings   = All settings used for current trial in AchillesGUI (struct)
%   SessionSettings = All settings used for current session in AchillesGUI (struct)
%   OutputData      = Complete set of experimental data (struct)

    % Retrieve all relevant outputs for post-trial analysis
    if (nargin == 1)
        OutputData = varargin{1};
        % Process experimental block to EMG ensembled data
        EMGEns = processBlocktoEnsemble(OutputData.EMGData,OutputData.TrialSettings);
        if (strcmp(OutputData.TrialSettings.feedbackMode,'SysID'))
            % Process experimental block to mechanical ensembled data
            MechEns = processMechtoEnsemble(OutputData.AchData,OutputData.TrialSettings,OutputData.SessionSettings);
            % Rough approximate offset between flush and thread
            correctedTrialIdxs = size(OutputData.AchData,1) - numel(OutputData.SysID.Reflexive) + OutputData.SysID.trialIdxs;
            % Remove transients from ensembled data
            MechEns = trimMechEnsemble(MechEns,OutputData.TrialSettings,correctedTrialIdxs);
            EMGEns = trimEMGEnsemble(EMGEns,OutputData.AchData,OutputData.EMGData,OutputData.TrialSettings,correctedTrialIdxs,MechEns.stretchIdxs);
        end
        TrialSettings = OutputData.TrialSettings;
        SessionSettings = OutputData.SessionSettings;
    elseif (nargin == 3)
        EMGEns = varargin{1};
        TrialSettings = varargin{2};
        SessionSettings = varargin{3};
    end

    % Plot stretch reflex ensembles (optionally, incl. subject-specific M1/M2 windows)
    figure;
    subplot(2,2,1)
        hold on; grid on;
        plot(EMGEns.tSeg,mean(EMGEns.rise.solReflex,2))    
    if (isfield(SessionSettings.AcrossSession,'M1Window'))
        yLim = get(gca,'YLim');
        plot([SessionSettings.AcrossSession.M1Window(1) SessionSettings.AcrossSession.M1Window(1)]/TrialSettings.fsEMG,yLim,'k--','LineWidth',1)
        plot([SessionSettings.AcrossSession.M1Window(2) SessionSettings.AcrossSession.M1Window(2)]/TrialSettings.fsEMG,yLim,'k--','LineWidth',1)
        if (strcmp(TrialSettings.feedbackMode,'EMG') && isfield(SessionSettings.AcrossSession,'M2Window'))
            plot([SessionSettings.AcrossSession.M2Window(1) SessionSettings.AcrossSession.M2Window(1)]/TrialSettings.fsEMG,yLim,'k--','LineWidth',1)
            plot([SessionSettings.AcrossSession.M2Window(2) SessionSettings.AcrossSession.M2Window(2)]/TrialSettings.fsEMG,yLim,'k--','LineWidth',1)
        end
    end
        title('Soleus')
        ylabel('EMG [\muV]')
    subplot(2,2,2)
        hold on; grid on;
        plot(EMGEns.tSeg,mean(EMGEns.rise.taReflex,2))
        title('Tib. Ant.')
    subplot(2,2,3)
        hold on; grid on;
        plot(EMGEns.tSeg,mean(EMGEns.rise.gmReflex,2))
        plot(EMGEns.tSeg,mean(EMGEns.rise.glReflex,2))
    if isfield(SessionSettings.AcrossSession,'M1WindowGA')
        yLim = get(gca,'YLim');
        plot([SessionSettings.AcrossSession.M1WindowGA(1) SessionSettings.AcrossSession.M1WindowGA(1)]/TrialSettings.fsEMG,yLim,'k--','LineWidth',1)
        plot([SessionSettings.AcrossSession.M1WindowGA(2) SessionSettings.AcrossSession.M1WindowGA(2)]/TrialSettings.fsEMG,yLim,'k--','LineWidth',1)
        if (strcmp(TrialSettings.feedbackMode,'EMG'))
            plot([SessionSettings.AcrossSession.M2WindowGA(1) SessionSettings.AcrossSession.M2WindowGA(1)]/TrialSettings.fsEMG,yLim,'k--','LineWidth',1)
            plot([SessionSettings.AcrossSession.M2WindowGA(2) SessionSettings.AcrossSession.M2WindowGA(2)]/TrialSettings.fsEMG,yLim,'k--','LineWidth',1)
        end
    end
        title('Gastroc. Med./Lat.')
        xlabel('Time [s]')
        ylabel('EMG [\muV]')
    subplot(2,2,4)
        hold on; grid on;
        plot(EMGEns.tSeg,EMGEns.rise.posReflex)
        title('Sync. Position')
        xlabel('Time [s]')
end