function [EMGEns,DataEMG] = processBlocktoEnsemble(EMGData,TrialSettings)
%processBlocktoEnsemble Process control/conditioning block to EMG ensembled data
%   Filter EMG measurement dataset and align/sort data based on stretch
%   reflex start indices measured with synchronization signal.
%
%	SYNTAX
%   [EMGEns,DataEMG] = processBlocktoEnsemble(EMGData,TrialSettings)
%
%	INPUTS
%   EMGData       = EMG measurement dataset (MxN double)
%   TrialSettings = All settings used for current trial in AchillesGUI (struct)
%
%   OUTPUT
%   EMGEns  = Aligned and sorted EMG signals (struct)
%   DataEMG = Selection of EMG signals (struct) [optional]

    % Length of EMG data segments
    if (strcmp(TrialSettings.feedbackMode,'SysID'))
        Settings.tSegStartEMG = 0.04;
        Settings.tSegEndEMG = 0.1;
    else
        Settings.tSegStartEMG = 0.1;
        Settings.tSegEndEMG = 0.12;
    end
    % Time characteristics
    DataEMG.dt = 1/TrialSettings.fsEMG; % [s] Porti EMG device
    % High-pass EMG to remove movement artifacts
    [bHpEMG,aHpEMG] = butter(TrialSettings.filtOrder,TrialSettings.filtHP/(1/(2*DataEMG.dt)),'high');
    % Select EMG signals & high-pass filter: Sol, TA, GM, GL, Sync (position-based)
    DataEMG.sol = abs(filter(bHpEMG,aHpEMG,detrend(EMGData(1,:)','constant'))); % [\muV] Soleus
    DataEMG.ta  = abs(filter(bHpEMG,aHpEMG,detrend(EMGData(2,:)','constant'))); % [\muV] Tib. Ant.
    DataEMG.gm  = abs(filter(bHpEMG,aHpEMG,detrend(EMGData(3,:)','constant'))); % [\muV] Gastroc. Med.
    DataEMG.gl  = abs(filter(bHpEMG,aHpEMG,detrend(EMGData(4,:)','constant'))); % [\muV] Gastroc. Lat.
    DataEMG.sync = EMGData(5,:)';                                               % [-]    Synchronization signal
    % Transform synchronize EMG signal to position
    DataEMG.pos = (EMGData(5,:) - EMGData(5,1))'/1e6;
    % Align and sort the EMG data
    EMGEns = alignSortEMGData(DataEMG,TrialSettings,Settings);
    % Store inter-stimulus intervals
    EMGEns.stimInterval = diff(EMGEns.stretchIdxs)/TrialSettings.fsEMG;
end