function [MechEns,DataMech] = processMechtoEnsemble(mechData,TrialSettings,SessionSettings)
%processMechtoEnsemble Process control/conditioning block to Mechanical ensembled data
%   Filter EMG measurement dataset and align/sort data based on stretch
%   reflex start indices measured with synchronization signal.
%
%	SYNTAX
%   [MechEns,DataMech] = processMechtoEnsemble(mechData,TrialSettings,SessionSettings)
%
%	INPUTS
%   mechData        = Mechanical measurement dataset (MxN double)
%   TrialSettings   = All settings used for current trial in AchillesGUI (struct)
%   SessionSettings = All settings used for current session in AchillesGUI (struct)
%
%   OUTPUT
%   MechEns  = Aligned and sorted (bio)mechanical signals (struct)
%	DataMech = Selection of (bio)mechanical signals (struct)

    % Length of (bio)mechanical data segments
    if (strcmp(TrialSettings.feedbackMode,'SysID'))
        Settings.tSegStart = 0.04;
        Settings.tSegEnd = 0.1;
    else
        Settings.tSegStart = 0.1;
        Settings.tSegEnd = 0.12;
    end
    % Filter settings
    Settings.fcLpPos = 200; % [Hz] Low-pass filter position for visualization
    % Time characteristics
    DataMech.dt = 1/TrialSettings.fsAch; % [s] Achilles Perturbator
    % Select (bio)mechanical signals: position/velocity/torque and reference
    DataMech.t       = mechData(:,1);                 % [s] Time vector data
    DataMech.posRef  = mechData(:,6) - mechData(1,6); % [rad] Position reference
    DataMech.posMeas = mechData(:,2) - mechData(1,2); % [rad] Position measured
    DataMech.velRef  = mechData(:,7);                 % [rad/s] Velocity reference
    DataMech.velMeas = mechData(:,3);                 % [rad/s] Velocity measured
    DataMech.tqMeas  = mechData(:,4);                 % [Nm] Torque measured
    % Center torque signal around zero (based on session or local torque norm)
    if ((strcmp(TrialSettings.feedbackMode,'SysID')) && (TrialSettings.isLocalTqNorm))
        DataMech.tqMeas = DataMech.tqMeas - TrialSettings.initialTorque;
    else
        DataMech.tqMeas = DataMech.tqMeas - SessionSettings.InitialTorque;
    end
    % Align and sort the (bio)mechanical data
    MechEns = alignSortMechData(DataMech,TrialSettings,Settings);
end