function [posSubplots] = subplotPositions(plotWidth,plotHeight,marginLeft,marginRight,marginBottom,marginTop,nPlotX,nPlotY,spacingX,spacingY)
%subplotPositions Determine (relative) position of all subplots
%   Determine the relative position of all subplots based on user-defined
%   plot dimensions (height/width,margins,spacing). Subplot{1} =
%   bottom-left corner, counting from left to right, then bottom to top. 
%
%	SYNTAX
%   [posSubplots] = subplotPositions(plotWidth,plotHeight,marginLeft,marginRight,marginBottom,marginTop,nPlotX,nPlotY,spacingX,spacingY)
%
%	INPUTS
%	plotWidth    = Width of full plot [cm] (double)
%   plotHeight   = Height of full plot [cm] (double)
%   marginLeft   = Left margin of full plot [cm] (double)
%   marginRight  = Right margin of full plot [cm] (double)
%   marginBottom = Bottom margin of full plot [cm] (double)
%   marginTop    = Top margin of full plot [cm] (double)
%   nPlotX       = Number of grid columns (double)
%   nPlotY       = Number of grid rows (double)
%   spacingX     = Width spacing between subplots [cm] (double)
%   spacingY     = Height spacing between subplots [cm] (double)
%
%	OUTPUT
%	posSubplots = (Relative) position subplot [left bottom width height] (MxN cell)

    % Pre-allocate output
    posSubplots = cell(nPlotX,nPlotY);
    % Determine size subplots (X,Y)
    subSizeX = (plotWidth-marginLeft-marginRight-spacingX*(nPlotX-1))/nPlotX;
    subSizeY = (plotHeight-marginTop-marginBottom-spacingY*(nPlotY-1))/nPlotY;
    
    for ii = 1:nPlotX
        for jj = 1:nPlotY
            % Determine (absolute) position subplot [left bottom] within plot
            subPosLeft = marginLeft+(ii-1)*(subSizeX+spacingX);
            subPosBottom = marginBottom+(jj-1)*(subSizeY+spacingY);
            % Determine (relative) position subplot [left bottom width height] within plot
            posSubplots{ii,jj} = [subPosLeft/plotWidth subPosBottom/plotHeight subSizeX/plotWidth subSizeY/plotHeight];
        end
    end
end