function [tEMG,syncPosEMG] = synchronizePosEMG(posMeas,syncEMG,pertAmpl,tMech,dtMech,dtEMG)
%synchronizePosEMG Synchronize EMG and (bio)mechanical data based on position sync
%   Synchronizes EMG and mechanical measurements based on a position 
%   synchronization signal measured twice: using the robotic system and
%   measured as digital trigger signal via the EMG system.
%
%	SYNTAX
%   [tEMG,syncPosEMG] = synchronizePosEMG(posMeas,syncEMG,pertAmpl,tMech,dtMech,dtEMG)
%
%	INPUTS
%   posMeas  = Measured position vector at motor encoder (Mx1 double)
%   syncEMG  = Digital trigger of EMG using analog position of motor encoder (Nx1 double)
%   pertAmpl = Amplitude (maximum - minimum) of perturbation signal [rad] (double)
%   tMech    = Time vector of mechanical data (Mx1 double)
%   dtMech   = Sampling time mechanical data [s] (double)
%   dtEMG    = Sampling time EMG [s] (double)
%
%   OUTPUTS
%   tEMG       = Synchronized time vector of EMG (Nx1 double)
%   syncPosEMG = Digital trigger of EMG converted to reference position(Nx1 double)
    
    % Generate histogram of synchronization signal, to retrieve signal minimum/maximum (without overshoots)
    [N,X] = hist(syncEMG,5000);
    [~,analogLow] = max(N(1:end/2)); analogLow = X(analogLow);
    [~,analogHigh] = max(N(ceil(end/2):end)); analogHigh = X(analogHigh+ceil(numel(X)/2)-1);
    % Scale EMG sync. signal to position vector
    syncPosEMG = (syncEMG-analogLow)/(analogHigh-analogLow)*pertAmpl - pertAmpl/2;
    % Resample EMG signal to motor sampling frequency, if unequal
    if (dtMech == dtEMG)
        syncPosEMGRes = syncPosEMG;
    elseif (dtMech > dtEMG)
        syncPosEMGRes = syncPosEMG(1:(dtMech/dtEMG):end);
    else
        syncPosEMGRes = reshape(repmat(syncPosEMG,1,dtEMG/dtMech)',[],1);
    end
    
    % Retrieve start and end of position & EMG signals; Co-locate midpoint
    % of first rising and last rising/falling edge of perturbation
    idxMechStart = find(posMeas > 0,1,'first');
    idxEMGStart = find(syncPosEMGRes > 0,1,'first');
    if (syncPosEMGRes(end) <= 0) % EMG finishes low, search falling edge
        idxEMGEnd = numel(syncPosEMGRes) - find(flipud(syncPosEMGRes) > 0,1,'first') + 1;
        if (posMeas(end) <= 0) % Mech also finishes low, direct falling edge search
            idxMechEnd = numel(posMeas) - find(flipud(posMeas) > 0,1,'first') + 1;
        else % Mech finishes high, skip to first low zone before falling edge search
            idxMechEnd = numel(posMeas) - (find(flipud(posMeas(1:find(posMeas <= 0,1,'last'))) > 0,1,'first') + numel(posMeas) - find(posMeas <= 0,1,'last')) + 1;
        end
    else % EMG finishes high, search rising edge
        idxEMGEnd = numel(syncPosEMGRes) - find(flipud(syncPosEMGRes) <= 0,1,'first') + 1;
        if (posMeas(end) <= 0) % Mech finishes low, skip to first high zone before rising edge search
            idxMechEnd = numel(posMeas) - (find(flipud(posMeas(1:find(posMeas > 0,1,'last'))) <= 0,1,'first') + numel(posMeas) - find(posMeas > 0,1,'last')) + 1;
        else % Mech also finishes low, direct rising edge search
            idxMechEnd = numel(posMeas) - find(flipud(posMeas) <= 0,1,'first') + 1;
        end
    end
    % Generate the EMG time vector from start to end, matching number of samples to sync signal
    tEMGRes = linspace(tMech(idxMechStart),tMech(idxMechEnd),idxEMGEnd - idxEMGStart + 1)';
    tEMGRes = [((-idxEMGStart+1):-1)'*mean(diff(tEMGRes))+tEMGRes(1); tEMGRes; (1:(numel(syncPosEMGRes)-idxEMGEnd))'*mean(diff(tEMGRes))+tEMGRes(end)];
    % Resample EMG signal back to original EMG samling frequency, if unequal
    if (dtMech == dtEMG)
        tEMG = tEMGRes;
    elseif (dtMech > dtEMG)
        tEMG = tEMGRes(1) + (0:numel(syncPosEMG)-1)'*mean(diff(tEMGRes))/2;
    else
        tEMG = tEMGRes(1:(dtEMG/dtMech):end);
    end
end