function [EMGEns,tEMG,trialIdxsEMG] = trimEMGEnsemble(EMGEns,mechData,EMGData,TrialSettings,trialIdxs,mechStretchIdxs)
%trimEMGEnsemble Remove outliers & transients from EMG ensembled data 
%   Trim the ensembled EMG dataset by removing the initial transient part
%   of each block as well as any outliers in terms of background
%   activations using the 'quartiles' method.
%
%	SYNTAX
%   [EMGEns,tEMG] = trimEMGEnsemble(EMGEns,mechData,EMGData,TrialSettings,trialIdxs,mechStretchIdxs)
%
%	INPUTS
%   EMGEns          = Aligned and sorted EMG signals (struct)
%   mechData        = Mechanical measurement dataset (MxN double)
%   EMGData         = EMG measurement dataset (MxN double)
%   TrialSettings   = All settings used for current trial in AchillesGUI (struct)
%   trialIdxs       = Indices of all feedback moments (Mx1 double)
%   mechStretchIdxs = Indices of all perturbation moments (Mx1 double)
%
%   OUTPUT
%   EMGEns       = Aligned and sorted EMG signals (struct)
%   tEMG         = Synchronized time vector EMG signals (Mx1 double)
%   trialIdxsEMG = Indices of all perturbation/feedback moments EMG signals (Mx1 double)

    % Synchronize EMG and (bio)mechanical data based on position sync.
    tMech = mechData(:,1);
    posMeas = mechData(:,2) - mechData(1,2) - TrialSettings.pertAmplitude/2;
    [tEMG,~] = synchronizePosEMG(posMeas,EMGData(5,:)',TrialSettings.pertAmplitude,tMech,1/TrialSettings.fsAch,1/TrialSettings.fsEMG);
    % Cross-link the Achilles-based indices to EMG-based indices
    [~,trialIdxsEMG] = min(bsxfun(@(x,y) abs(x-y), tEMG, tMech(trialIdxs)'));
        
    % Remove transients from ensemble data (take from synchronization with mech. data with some lenience)
    [~,emgStretchIdxs] = min(bsxfun(@(x,y) abs(x-y), tEMG, tMech([mechStretchIdxs(1) mechStretchIdxs(end)])'));
    startStopIdxs = (EMGEns.stretchIdxs >= (emgStretchIdxs(1)-200) & EMGEns.stretchIdxs < (emgStretchIdxs(end)+200));
    % Trim the entire ensemble with all (sub-)structures eliminating
    % indices within the transient periods
    EMGEns.stretchIdxs = EMGEns.stretchIdxs(startStopIdxs);
    EMGEns.stimInterval = EMGEns.stimInterval(startStopIdxs);
    EMGEns.rise = structfun(@(x) x(:,startStopIdxs),EMGEns.rise,'UniformOutput',false);
    
    % Remove all Sol Background outliers (based on 1.5*(q3-q1)) from EMG ensemble
    EMGEns.stretchIdxsRed = EMGEns.stretchIdxs(~isoutlier(mean(EMGEns.rise.solBack),'quartiles'));
    EMGEns.rise = structfun(@(x) x(:,~isoutlier(mean(EMGEns.rise.solBack),'quartiles')),EMGEns.rise,'UniformOutput',false);
end