%% Clean Start
clc, clearvars, close all;

%% Settings
% Experiment and Subject IDs to-be processed
Settings.experimentID = {'201906-07_ReplicateMrachacz','201908-09_PilotMonkeyBusiness','201911-12_PilotSystemIdentification'}; % Experiment identifier
Settings.subjectID = [{'001','002','003'};{'004','005','006'};{'007','008','009'}]; % Subject identifier (padded to 3 numbers)
% Experimental and processing settings (flags)
Settings.feedbackMode = {'EMG','EMG','SysID'}; % Flag if feedback provided on 'EMG' or 'SysID'
Settings.isPlot = 0; % Flag to generate plots during processing (if true)
% Define data storage location
dataCD = cd; fileSepIdxs = strfind(dataCD,filesep);
dataCD = dataCD(1:fileSepIdxs(end)-1);

% Add folder with all shared functions
addpath(genpath('Functions'));

%% Processing
for mm = 1:numel(Settings.experimentID)
    % Clear all variables per Experiment
    clearvars -except mm dataCD Settings
    % Run baseline analysis
    run baselineAnalysis;
    
    % Run conditioning analysis
    for ii = size(Settings.subjectID,1):-1:1
        %% General
        % Retrieve all experimental folders/files
        subjectDir = dir([dataCD '/Data/' Settings.experimentID{mm} '/Stretch_Conditioning/']);
        % Retrieve path/name of all folders belonging to specific subject
        subjectDir = {subjectDir(cellfun(@any,regexp({subjectDir.name},['Subject' Settings.subjectID{mm,ii}]))).name}';

        %% H-M Recruitment curve
        % Pre-allocate (intermediate) outcome measures
        DataCondition(ii,1).mMax = zeros(numel(subjectDir),1);

        for jj = 1:numel(subjectDir)
            % Retrieve path/name of all H-M recruitment curve trials
            dirContent = dir([dataCD '/Data/' Settings.experimentID{mm} '/Stretch_Conditioning/' subjectDir{jj} '/E02_HMRecruitment/*.mat']);
            dirContent = {dirContent.name}';

            % Load last (=only or combined/correct) trial and process results
            load([dataCD '/Data/' Settings.experimentID{mm} '/Stretch_Conditioning/' subjectDir{jj} '/E02_HMRecruitment/' dirContent{end}]);
            DataHM = calcHMCurve(OutputData.EMGData,OutputData.TrialSettings,OutputData.SessionSettings);
            DataCondition(ii).mMax(jj) = max(mean(DataHM.mWaveSize,2));
        end

        %% Control Block
        % Pre-allocate (intermediate) outcome measures
        DataCondition(ii).solBackBlockControl = cell(numel(subjectDir),1);
        DataCondition(ii).solBackControl = zeros(numel(subjectDir),1);
        DataCondition(ii).taBackBlockControl = cell(numel(subjectDir),1);
        DataCondition(ii).taBackControl = zeros(numel(subjectDir),1);
        DataCondition(ii).tqBackBlockControl = cell(numel(subjectDir),1);
        DataCondition(ii).tqBackControl = zeros(numel(subjectDir),1);
        DataCondition(ii).solM1BlockControl = cell(numel(subjectDir),1);
        DataCondition(ii).solM1Control = zeros(numel(subjectDir),1);
        if (strcmp(Settings.feedbackMode{mm},'SysID'))
            DataCondition(ii).ankleGControl = zeros(numel(subjectDir),1);
        end
        DataCondition(ii).stimIntControl = zeros(numel(subjectDir),1);

        for jj = 1:numel(subjectDir)
            % Retrieve path/name of all Control trials
            dirContent = dir([dataCD '/Data/' Settings.experimentID{mm} '/Stretch_Conditioning/' subjectDir{jj} '/E03_ControlTrials/*.mat']);
            dirContent = {dirContent.name}';

            % First trial contains the 'control' block
            load([dataCD '/Data/' Settings.experimentID{mm} '/Stretch_Conditioning/' subjectDir{jj} '/E03_ControlTrials/' dirContent{1}]);
            % Process experimental block to EMG/Mechanical ensembled data
            EMGEns = processBlocktoEnsemble(OutputData.EMGData,OutputData.TrialSettings);
            MechEns = processMechtoEnsemble(OutputData.AchData,OutputData.TrialSettings,OutputData.SessionSettings);
            if (strcmp(OutputData.TrialSettings.feedbackMode,'SysID'))
                % Rough approximate offset between flush and thread
                correctedTrialIdxs = size(OutputData.AchData,1) - numel(OutputData.SysID.Reflexive) + OutputData.SysID.trialIdxs;
                % Remove transients from ensembled data
                MechEns = trimMechEnsemble(MechEns,OutputData.TrialSettings,correctedTrialIdxs);
                EMGEns = trimEMGEnsemble(EMGEns,OutputData.AchData,OutputData.EMGData,OutputData.TrialSettings,correctedTrialIdxs,MechEns.stretchIdxs);
            end
            % Plot stretch reflex ensemble data
            if (Settings.isPlot)
                OutputData.SessionSettings.AcrossSession.M1Window = AcrossSession(ii).M1Window;
                plotStretchEnsembles(EMGEns,OutputData.TrialSettings,OutputData.SessionSettings);
            end
            % Process ensembled data to (intermediate) outcome measures
            % SOL/TA background activity (mean before perturbation onset)
            DataCondition(ii).solBackBlockControl{jj} = mean(EMGEns.rise.solBack)';
            DataCondition(ii).taBackBlockControl{jj} = mean(EMGEns.rise.taBack)';
            if (strcmp(OutputData.TrialSettings.feedbackMode,'SysID'))
                % Tq background activity (timeseries) retrieved from online processing 
                MechEns.rise.tqBack = MechEns.rise.tqBack(:,ismember(EMGEns.stretchIdxs,EMGEns.stretchIdxsRed));
            end
            % Torque background activity (mean before perturbation onset)
            DataCondition(ii).tqBackBlockControl{jj} = mean(MechEns.rise.tqBack)';
            % SOL M1 reflex response (rms within M1-window)
            DataCondition(ii).solM1BlockControl{jj} = rms(max(EMGEns.rise.solReflex((AcrossSession(ii).M1Window(1):AcrossSession(ii).M1Window(2))+1,:) - mean(EMGEns.rise.solBack),0))';
            if (strcmp(OutputData.TrialSettings.feedbackMode,'EMG'))
                % Mean stimulation interval per block
                DataCondition(ii).stimIntControl(jj) = mean(EMGEns.stimInterval);
            else
                % Mean reflexive joint impedance gain (G) per block
                DataCondition(ii).ankleGControl(jj) = mean(-OutputData.SysID.Reflexive(OutputData.SysID.trialIdxs));
                % Mean stimulation interval per block
                DataCondition(ii).stimIntControl(jj) = mean(diff(OutputData.SysID.trialIdxs)/OutputData.TrialSettings.fsAch);
            end
            % Compute mean per block for all measures
            DataCondition(ii).solBackControl(jj) = mean(DataCondition(ii).solBackBlockControl{jj});
            DataCondition(ii).taBackControl(jj) = mean(DataCondition(ii).taBackBlockControl{jj});
            DataCondition(ii).tqBackControl(jj) = mean(DataCondition(ii).tqBackBlockControl{jj});
            DataCondition(ii).solM1Control(jj) = mean(DataCondition(ii).solM1BlockControl{jj});
        end

        %% Conditioning Block
        % Pre-allocate (intermediate) outcome measures
        DataCondition(ii).solBackBlockCond = cell(numel(subjectDir),3);
        DataCondition(ii).solBackCond = zeros(numel(subjectDir),3);
        DataCondition(ii).taBackBlockCond = cell(numel(subjectDir),3);
        DataCondition(ii).taBackCond = zeros(numel(subjectDir),3);
        DataCondition(ii).tqBackBlockCond = cell(numel(subjectDir),3);
        DataCondition(ii).tqBackCond = zeros(numel(subjectDir),3);
        DataCondition(ii).solM1BlockCond = cell(numel(subjectDir),3);
        DataCondition(ii).solM1Cond = zeros(numel(subjectDir),3);
        if (strcmp(Settings.feedbackMode{mm},'SysID'))
            DataCondition(ii).ankleGCond = zeros(numel(subjectDir),3);
            DataCondition(ii).fbPerfCond = zeros(numel(subjectDir),3,75,2);
        end
        DataCondition(ii).stimIntCond = zeros(numel(subjectDir),3);

        for jj = 1:numel(subjectDir)
            % Retrieve path/name of all Conditioning trials
            dirContent = dir([dataCD '/Data/' Settings.experimentID{mm} '/Stretch_Conditioning/' subjectDir{jj} '/E04_ConditioningTrials/*.mat']);
            dirContent = {dirContent.name}';

            % Second-Fourth trial contains the 'conditioning' block
            for kk = 1:3
                load([dataCD '/Data/' Settings.experimentID{mm} '/Stretch_Conditioning/' subjectDir{jj} '/E04_ConditioningTrials/' dirContent{kk}]);
                % Process experimental block to EMG/Mechanical ensembled data
                EMGEns = processBlocktoEnsemble(OutputData.EMGData,OutputData.TrialSettings);
                MechEns = processMechtoEnsemble(OutputData.AchData,OutputData.TrialSettings,OutputData.SessionSettings);
                if (strcmp(OutputData.TrialSettings.feedbackMode,'SysID'))
                    % Rough approximate offset between flush and thread
                    correctedTrialIdxs = size(OutputData.AchData,1) - numel(OutputData.SysID.Reflexive) + OutputData.SysID.trialIdxs;
                    % Remove transients from ensembled data
                    MechEns = trimMechEnsemble(MechEns,OutputData.TrialSettings,correctedTrialIdxs);
                    [EMGEns,~,trialIdxsEMG] = trimEMGEnsemble(EMGEns,OutputData.AchData,OutputData.EMGData,OutputData.TrialSettings,correctedTrialIdxs,MechEns.stretchIdxs);
                end
                % Plot stretch reflex ensemble data
                if (Settings.isPlot)
                    OutputData.SessionSettings.AcrossSession.M1Window = AcrossSession(ii).M1Window;
                    plotStretchEnsembles(EMGEns,OutputData.TrialSettings,OutputData.SessionSettings);
                end
                % Process ensembled data to (intermediate) outcome measures
                % SOL/TA background activity (mean before perturbation onset)
                DataCondition(ii).solBackBlockCond{jj,kk} = mean(EMGEns.rise.solBack)';
                DataCondition(ii).taBackBlockCond{jj,kk} = mean(EMGEns.rise.taBack)';
                if (strcmp(OutputData.TrialSettings.feedbackMode,'SysID'))
                    % Tq background activity (timeseries) retrieved from online processing
                    MechEns.rise.tqBack = MechEns.rise.tqBack(:,ismember(EMGEns.stretchIdxs,EMGEns.stretchIdxsRed));
                end
                % Torque background activity (mean before perturbation onset)
                DataCondition(ii).tqBackBlockCond{jj,kk} = mean(MechEns.rise.tqBack)';
                % SOL M1 reflex response (rms within M1-window)
                DataCondition(ii).solM1BlockCond{jj,kk} = rms(max(EMGEns.rise.solReflex((AcrossSession(ii).M1Window(1):AcrossSession(ii).M1Window(2))+1,:) - mean(EMGEns.rise.solBack),0))';
                if (strcmp(OutputData.TrialSettings.feedbackMode,'EMG'))
                    % Mean stimulation interval per block
                    DataCondition(ii).stimIntCond(jj,kk) = mean(EMGEns.stimInterval);
                else
                    % Mean reflexive joint impedance gain (G) per block
                    DataCondition(ii).ankleGCond(jj,kk) = mean(-OutputData.SysID.Reflexive(OutputData.SysID.trialIdxs));
                    % Mean stimulation interval per block
                    DataCondition(ii).stimIntCond(jj,kk) = mean(diff(OutputData.SysID.trialIdxs)/OutputData.TrialSettings.fsAch);
                    % Store the EMG-based and impedance-based reflex magnitudes at each feedback instances within a block
                    stretchesPerTrial = EMGEns.stretchIdxsRed < trialIdxsEMG & EMGEns.stretchIdxsRed > [0 trialIdxsEMG(1:end-1)];
                    DataCondition(ii).fbPerfCond(jj,kk,:,:) = [-OutputData.SysID.Reflexive(OutputData.SysID.trialIdxs), (DataCondition(ii).solM1BlockCond{jj,kk}'*(stretchesPerTrial./sum(stretchesPerTrial)))'];
                end
                % Compute mean per block for all measures
                DataCondition(ii).solBackCond(jj,kk) = mean(DataCondition(ii).solBackBlockCond{jj,kk});
                DataCondition(ii).taBackCond(jj,kk) = mean(DataCondition(ii).taBackBlockCond{jj,kk});
                DataCondition(ii).tqBackCond(jj,kk) = mean(DataCondition(ii).tqBackBlockCond{jj,kk});
                DataCondition(ii).solM1Cond(jj,kk) = mean(DataCondition(ii).solM1BlockCond{jj,kk});
            end
        end

        %% Outcome Measures
        % Store all relevent measures used within the further data processing scripts in new Results-struct
        % Interstimulus time
        ResultsCondition(ii,1).stimInterval = [DataCondition(ii).stimIntControl, DataCondition(ii).stimIntCond];
        % H-M Recruitment
        ResultsCondition(ii).mMax = DataCondition(ii).mMax;

        % SOL/TA/Torque Background Activity  (per block and mean of block)
        ResultsCondition(ii).solBackBlock = [DataCondition(ii).solBackBlockControl, DataCondition(ii).solBackBlockCond];
        ResultsCondition(ii).solBack      = [DataCondition(ii).solBackControl, DataCondition(ii).solBackCond];
        ResultsCondition(ii).taBackBlock  = [DataCondition(ii).taBackBlockControl, DataCondition(ii).taBackBlockCond];
        ResultsCondition(ii).taBack       = [DataCondition(ii).taBackControl, DataCondition(ii).taBackCond];
        ResultsCondition(ii).tqBackBlock  = [DataCondition(ii).tqBackBlockControl, DataCondition(ii).tqBackBlockCond];
        ResultsCondition(ii).tqBack       = [DataCondition(ii).tqBackControl, DataCondition(ii).tqBackCond];

        % SOL M1 Reflexive Activity
        ResultsCondition(ii).solM1 = [DataCondition(ii).solM1Control, DataCondition(ii).solM1Cond];
        % Normalized (100% baseline) SOL M1 per block (control and conditioned reflexes separately)
        ResultsCondition(ii).solM1BlockControlNorm = cellfun(@(x) x/mean(DataBaseline(ii).solM1Control(2:6),'omitnan')*100,DataCondition(ii).solM1BlockControl,'UniformOutput',false);
        ResultsCondition(ii).solM1BlockCondNorm = cellfun(@(x) x/mean(mean(DataBaseline(ii).solM1Cond(2:6,:),2,'omitnan'),'omitnan')*100,DataCondition(ii).solM1BlockCond,'UniformOutput',false);
        % Normalized (100% baseline SOL M1 mean of block
        ResultsCondition(ii).solM1Norm = [DataCondition(ii).solM1Control/mean(DataBaseline(ii).solM1Control(2:6),'omitnan'),DataCondition(ii).solM1Cond/mean(mean(DataBaseline(ii).solM1Cond(2:6,:),2,'omitnan'),'omitnan')]*100;
        if (strcmp(Settings.feedbackMode{mm},'SysID'))
            % Reflexive gain G (+normalized 100% baseline)
            ResultsCondition(ii).ankleG = [DataCondition(ii).ankleGControl, DataCondition(ii).ankleGCond];
            ResultsCondition(ii).ankleGNorm = [DataCondition(ii).ankleGControl/mean(DataBaseline(ii).ankleGControl(2:6),'omitnan'),DataCondition(ii).ankleGCond/mean(mean(DataBaseline(ii).ankleGCond(2:6,:),2,'omitnan'),'omitnan')]*100;
            ResultsCondition(ii).fbPerfCond = DataCondition(ii).fbPerfCond;
        else  % No reflexive gain G for first two participant groups
            ResultsCondition(ii).ankleG = NaN(6,4);
            ResultsCondition(ii).ankleGNorm = NaN(6,4);
            ResultsCondition(ii).fbPerfCond = NaN(6,4,75,2);
        end
    end

    %% Save Results
%     save([cd '/Processed/' Settings.experimentID{mm} '/outcomeMeasures.mat'],'AcrossSession','ResultsBaseline','ResultsCondition','-v7.3')
end